*
*  Test program for Sheriff
*

#define PRODUCT_ID			"9758-3050-1918-9292-6466"
#define LICENSE_PATH		"d:\temp\vfp"
#define USER_NAME			"Sheriff-FoxPro Demo User"

#include const.h
#include slsapi.h

*-
* DECLARE DLL statements for Sheriff API
*-
DECLARE LONG SLS_Register IN SlsApi ;
  String pszProductID, String pszProductName, ;
  String pszLicensePath

DECLARE LONG SLS_Request IN SlsApi ;
  String pszProductID, String pszUserName, ;
  String SLS_REQUEST, STRING @SLS_PERMIT, ;
  Long @plLicenseHandle, STRING @SLS_CHALLENGE

DECLARE LONG SLS_Update IN SlsApi ;
  String pszProductID, Long lLicenseHandle, ;
  String SLS_UPDATE, String @SLS_PERMIT, ;
  String @SLS_CHALLENGE

DECLARE LONG SLS_Release IN SlsApi ;
  String pszProductID, Long lLicenseHandle, ;
  String SLS_RELEASE, String @SLS_CHALLENGE

DECLARE LONG SLS_GetReference IN SlsApi ;
  String pszProductID, String @pszReference


DECLARE LONG SLS_License IN SlsApi ;
  String pszProductID, String SLS_LICENSE, ;
  String @SLS_CHALLENGE

DECLARE LONG SLS_SetLicence IN SlsApi ;
  String pszProductID, String pszReference, ;
  String pszLicenseKey

DECLARE LONG SLS_QueryLicenceInfo IN SlsApi ;
  String pszProductID, String @SLS_LICENSE_INFO

*-
* The next two functions are only
* used if Challenge is implemented
*-
DECLARE LONG SLS_CreateChallenge IN SlsApi ;
  String SLS_SECRET, Integer nSecrectSize, ;
  String pbStream, Integer nStreamSize, ;
  String @SLS_CHALLENGE

DECLARE LONG SLS_VerifyChallenge IN SlsApi ;
  String SLS_SECRET, Integer nSecrectSize, ;
  String pbStream, Integer nStreamSize, ;
  String @SLS_CHALLENGE

*-SLS_GetErrorMessage
*-Get Error Message. pszErrorMessage points to buffer allocated by caller,
*-the minimum length of the buffer is 256 bytes
DECLARE LONG SLS_GetErrorMessage IN SlsApi ;
  Long hr, String @pszErrorMessage

*-Others
DECLARE LONG SLS_IsProductInstalled IN SlsApi ;
  String pszProductID
                    
DECLARE LONG SLS_SetReclaimTime IN SlsApi ;
  Long nMinutes

DECLARE LONG SLS_SetOptions In SlsApi;
  String pszProductID, Long lLicenseHandle, ;
  String SLS_OPTIONS, String @SLS_CHALLENGE


SET PROCEDURE TO ConvertAPI.prg ADDITIVE
SET PROCEDURE TO Sheriff.prg ADDITIVE


*-
* Set up some public memvars
*-

DIMENSION gaSecrets[4]
gaSecrets[1] = "0763-1985-3207-6621"
gaSecrets[2] = "1854-2076-4198-7532"
gaSecrets[3] = "2482-1593-2604-4927"
gaSecrets[4] = "3739-0628-9517-9618"

PUBLIC	oSheriff

*-
* Instantiate Sheriff
*-
oSheriff = CREATEOBJECT("Sheriff",PRODUCT_ID, USER_NAME)     

* Each secret code is 32 byteslong at maximum including a null terminator
* the cPadding below is to make up the 32 bytes, its contents can be anything
cPadding="123456789012"
cSecrets=gaSecrets[1]+chr(0)+cPadding+;
		 gaSecrets[2]+chr(0)+cPadding+;
		 gaSecrets[3]+chr(0)+cPadding+;
		 gaSecrets[4]+chr(0)+cPadding

oSheriff.SetSecrets(cSecrets)
        
lnRunMode = CheckLicence()
if(lnRunMode = RUN_FULL)
*Run in full licensed mode
*take appropriate actions here
	MESSAGEBOX("Welcome! Run in full mode",64,"Sheriff-VFP Demo")
	*-now application is running, you need to setup a timer
	*-in which you call Sheriff's updates method regularly for "heart-beating"
	
	*-enter your application's main tasks
	*-do whatever you like to do
	
	*-before exit application, call Sheriff's releases method to release licence
	LOCAL cRelease
	cRelease=REPLICATE(CHR(0),4)
	oSheriff.Releases(cRelease)
	RELEASE oSheriff
	return
endif
if(lnRunMode = RUN_DEMO)
*Run in demo mode only
*take appropriate actions here
	MESSAGEBOX("Welcome! Run in DEMO mode",64,"Sheriff-VFP Demo")
	RELEASE oSheriff
	return
endif

*exit without doing anythng
	RELEASE oSheriff
RETURN  && END OF MAIN

FUNCTION CheckLicence()

	LOCAL cRequest, Permit
	cRequest=REPLICATE(CHR(0),4)
	cPermit=REPLICATE(CHR(0),8)
	
	if(oSheriff.Request(cRequest,@cPermit))
	    *test only
		glAccessKey=FROMLONG(SUBSTR(cPermit,5,4))
		cLicenceInfo=REPLICATE(CHR(0),52)
		oSheriff.QueryLicenceInfo(@cLicenceInfo)
		return RUN_FULL
	endif
	
	*If reach here, request failed
	bRegister=.F.
	if(oSheriff.GetLastError()=SLS_E_LICENCE_UNREGISTERED)
	*to register product
		if(!oSheriff.Register("Sheriff Demo",LICENCE_PATH))
			=ShowSheriffError()
			return RUN_EXIT
		endif
		bRegister=.T.
	endif
		
	if(oSheriff->GetLastError()=SLS_E_LICENCE_UNDEFINED or bRegister=.T.)
	*to register licence
		do form Register.scx to WhatToDo
		if(WhatToDo = TO_REGISTER)
		*To register licence
			if(RegisterLicence())
			   return RUN_FULL
			else
			   return RUN_EXIT
			endif
		endif
		if(WhatToDo = TO_CONTINUE)
		*To continue run in demo mode			
			return RUN_DEMO	
		endif
		*- exit completely
		return RUN_EXIT
	endif
	if(m_pSheriff->GetLastError()==SLS_E_LICENCE_EXPIRED)
	*to deal with expired licecnce
	*take appropriate actions here
		MESSAGEBOX("Your licence has expired",64,"Sheriff-VFP Demo")
		*-perhaps you want to ask the user to renew his/her licence
		return RUN_EXIT
	endif
	if(oSheriff.GetLastError()=SLS_E_LICENCE_EXCEEDED)
	*to deal with too many users
	*take appropriate actions here
		MESSAGEBOX("There are too many users login at the moment",64,"Sheriff-VFP Demo")
		*-maybe you can offer the user the demo or
		*-ask the user to try again later
		return RUN_EXIT
	endif

	*Other errors
	=ShowSheriffError()
	return RUN_EXIT
	
ENDFUNC

FUNCTION RegisterLicence()
	*Get Reference Code
	cReferenceCode=SPACE(64)
	if(!oSheriff->GetReference(@cReferenceCode))
		=ShowSheriffError()
		return .F.
	endif
	
	DO FORM License.scx with cReferenceCode to cLicenceKey
	if(!EMPTY(cLicenceKey))
		if(!oSheriff.SetLicence(cReferenceCode,cLicenceKey))
			=ShowSheriffError()
			return .F.
		endif
		
		*request licence
		LOCAL cRequest, Permit
		cRequest=REPLICATE(CHR(0),4)
		cPermit=REPLICATE(CHR(0),8)
		
		if(!oSheriff.Request(cRequest,@cPermit))
			=ShowSheriffError()
			return .F.
		endif
		*licence has been registered successfully
		return .T.
	endif
	
	*if reach here, the user has choosen not to register
	return .F.	
ENDFUNC

PROCEDURE ShowSheriffError()

	LOCAL cErrorMessage
	cErrorMessage=SPACE(256)
	oSheriff.GetLastErrorMessage(cErrorMessage)
	MESSAGEBOX(cErrorMessage,48,"Sheriff Error")

ENDPROC


